@@ -1052,13 +1052,45 @@ bool DialogicTrunk::dialISDN(char digit[16], int timeout)
 {
 	MAKECALL_BLK makecall_blk;
 	int rtn;
+	const char *cp;
 
 	makecall_blk.isdn.BC_xfer_cap=BEAR_CAP_SPEECH;
 	makecall_blk.isdn.BC_xfer_mode=ISDN_ITM_CIRCUIT;
 	makecall_blk.isdn.BC_xfer_rate=BEAR_RATE_64KBPS;
-	makecall_blk.isdn.facility_coding_value = ISDN_CPN;
+
+	// try trunk group first for override by group
+
+	cp = group->getLast("isdnfacility");
+	if(!cp)
+		cp = dialogicivr.getLast("isdnfacility");
+	if(!cp)
+		cp = "cpn";
+
+	if(!stricmp(cp, "none"))
+		makecall_blk.isdn.facility_coding_value = ISDN_NOTUSED;
+	else if(!stricmp(cp, "cpn"))
+		makecall_blk.isdn.facility_coding_value = ISDN_CPN;
+	else if(!stricmp(cp, "bn"))
+		makecall_blk.isdn.facility_coding_value = ISDN_BN;
+	else
+		makecall_blk.isdn.facility_coding_value = ISDN_CPN;
+
 	makecall_blk.isdn.destination_number_type = EN_BLOC_NUMBER;
-	makecall_blk.isdn.destination_number_plan = ISDN_NUMB_PLAN;
+
+	cp = group->getLast("isdnnumbering");
+	if(!cp)
+		cp = dialogicivr.getLast("isdnnumbering");
+	if(!cp)
+		cp = "isdn";
+
+	if(!stricmp(cp, "none") || !stricmp(cp, "unknown"))
+		makecall_blk.isdn.destination_number_plan = UNKNOWN_NUMB_PLAN;
+	else if(!stricmp(cp, "e.164") || !stricmp(cp, "telephony"))
+		makecall_blk.isdn.destination_number_plan = TELEPHONY_NUMB_PLAN;
+	else if(!strnicmp(cp, "priv", 4))
+		makecall_blk.isdn.destination_number_plan = PRIVATE_NUMB_PLAN;
+	else
+		makecall_blk.isdn.destination_number_plan = ISDN_NUMB_PLAN;
 
 	if(data.dialxfer.callingdigit)
 	{
@@ -1075,7 +1107,19 @@ bool DialogicTrunk::dialISDN(char digit[16], int timeout)
 		makecall_blk.isdn.origination_phone_number[0] = '\0';
 	}
 	makecall_blk.isdn.facility_feature_service = ISDN_SERVICE;
-	makecall_blk.isdn.usrinfo_layer1_protocol = ISDN_UIL1_G711ALAW;
+
+	cp = group->getLast("isdnencoding");
+	if(!cp)
+		cp = dialogicivr.getLast("isdnencoding");
+	if(!cp)
+		cp = "alaw";
+
+	if(!stricmp(cp, "ulaw") || !stricmp(cp, "mulaw"))
+		makecall_blk.isdn.usrinfo_layer1_protocol = ISDN_UIL1_G711ULAW;
+	else if(!stricmp(cp, "adpcm"))
+		makecall_blk.isdn.usrinfo_layer1_protocol = ISDN_UIL1_G721ADCPM;
+	else
+		makecall_blk.isdn.usrinfo_layer1_protocol = ISDN_UIL1_G711ALAW;
 	makecall_blk.isdn.usr_rate = ISDN_NOTUSED;
 	makecall_blk.isdn.usrinfo_bufp = NULL;
 	makecall_blk.isdn.nsfc_bufp = NULL;
