@@ -117,8 +117,10 @@ bool PikaTrunk::ringHandler(TrunkEvent *event)
 				{
 				case MPT_REASON_FOR_ABSENCE_OF_DIRECTORY_NUMBER:
 				case MPT_CALLING_LINE_DIRECTORY_NUMBER:
-					memcpy(script, data, msgsize);
-					script[msgsize] = 0;
+					strcpy(script, "pstn:");
+					memcpy(script + 5, data, msgsize);
+					script[msgsize + 5] = 0;
+					setConstant(SYM_CLID, script + 5);
 					setConstant(SYM_CALLER, script);
 					break;
 				case MPT_REASON_FOR_ABSENCE_OF_NAME:
@@ -165,7 +167,7 @@ bool PikaTrunk::ringHandler(TrunkEvent *event)
 			return true;
 		}
 		rings = 0;
-		slog(SLOG_ERROR) << pikaivr.getCardName(card) << id << ": " << script << ": cannot answer call" << endl;	
+		slog(SLOG_ERROR) << pikaivr.getCardName(card) << id <<": cannot answer call" << endl;	
 		return true;
 	case TRUNK_LINE_WINK:
 		if(!flags.offhook)
