@@ -291,11 +291,13 @@ static void spell(strstream *s, const char *text)
 static void parsedate(const char *text, int *month, int *day, int *year)
 {
 	if(text[2] == '/')
-		sscanf(text, "%02d/%02d/%04d", month, day, year);
+		sscanf(text, "%02d/%02d/%04d", &month, &day, &year);
 	else if(text[2] == '.')
-		sscanf(text, "%02d.%02d.%04d", day, month, year);
+		sscanf(text, "%02d.%02d.%04d", &day, &month, &year);
+	else if(text[4] == '-')
+		sscanf(text, "%04d-%02d-%02d", &year, &month, &day);
 	else
-		sscanf(text, "%04d%02d%02d", year, month, day);
+		sscanf(text, "%04d%02d%02d", &year, &month, &day);
 }
 
 static void saydate(strstream *s, const char *text)
