@@ -2464,6 +2464,27 @@ protected:
  	 */
 	Symbol *getEntry(const char *symname, int size);
 
+#ifndef	SCRIPT_SG_VARIABLES
+        /**
+         * Provides interface for setting local or global variable
+         * passed by reference to drivers and such.
+         *
+         * @return true if successful
+         * @param symbol name.
+         * @param symbol size to allocate if new.
+         * @param symbol value.
+         */
+        bool setVariable(const char *id, int size, const char *value = NULL);
+
+        /**
+         * Accesses local or global variable by direct name reference.
+         *
+         * @return content
+         * @param symbol name.
+         */
+        const char *getVariable(const char *id);
+#endif
+
 	/**
 	 * A derived Commit handler, allows "clear %digits", etc.
 	 *
