@@ -165,10 +165,7 @@ bool Trunk::scrStatinfo(void)
 			snprintf(value, sizeof(value), "%d", grp->max.outgoing);
 
 		if(value[0])
-		{
-			setSymbol(var, 11);
-			setSymbol(var, value);
-		}
+			setVariable(var, 11, value);
 	}
 	advance();
 	return true;		
@@ -225,8 +222,7 @@ bool Trunk::scrHuntinfo(void)
 			opt = def->data;
 		else
 			opt = sym->data;
-		setSymbol(var, def->flags.size);
-		setSymbol(var, opt);
+		setVariable(var, def->flags.size, opt);
 	}
 	advance();
 	return true;
@@ -292,8 +288,7 @@ bool Trunk::scrUserinfo(void)
 			opt = def->data;
 		else
 			opt = sym->data;
-		setSymbol(var, def->flags.size);
-		setSymbol(var, opt);
+		setVariable(var, def->flags.size, opt);
 	}
 	advance();
 	return true;
@@ -698,8 +693,7 @@ bool Trunk::scrSend(void)
 			if(!sym)
 				continue;
 
-			trk->setSymbol(opt, sym->flags.size);
-			trk->setSymbol(opt, sym->data);
+			trk->setVariable(opt, sym->flags.size, sym->data);
 		}
 		trk->leaveMutex();
 	}
@@ -766,10 +760,9 @@ bool Trunk::scrAssign(void)
 		value = "";
 
 	if(!size)
-		setSymbol(var, getSymbolSize());
+		setVariable(var, getSymbolSize(), value);
 	else
-		setSymbol(var, atoi(size));
-	setSymbol(var, value);
+		setVariable(var, atoi(size), value);
 	advance();
 	return true;
 }
@@ -1258,12 +1251,14 @@ bool Trunk::scrModule(void)
 	return false;
 }
 
+
 bool Trunk::scrMove(void)
 {
 	const char *prefix = getPrefixPath();
-	const char *n1 = getValue(NULL);
-	const char *n2 = getValue(NULL);
+	char *n1 = getValue(NULL);
+	char *n2 = getValue(NULL);
 	char buf1[256], buf2[256];
+	const char *ext;
 
 	if(!n1 || !n2)
 	{
@@ -1273,11 +1268,53 @@ bool Trunk::scrMove(void)
 
 	if(prefix)
 	{
-		snprintf(buf1, sizeof(buf1), "%s/%s", prefix, n1);
-		snprintf(buf2, sizeof(buf2), "%s/%s", prefix, n2);
-		n1 = (const char *)buf1;
-		n2 = (const char *)buf2;
+		snprintf(buf1, sizeof(buf1) - 5, "%s/%s", prefix, n1);
+		snprintf(buf2, sizeof(buf2) - 5, "%s/%s", prefix, n2);
 	}
+	else
+	{
+		snprintf(buf1, sizeof(buf1) - 5, "%s", n1);
+		snprintf(buf2, sizeof(buf2) - 5, "%s", n2);
+	}
+	n1 = buf1;
+	n2 = buf2;
+
+	ext = strrchr(n1, '/');
+	if(ext)
+		ext = strchr(ext, '.');
+	else
+	{
+		error("move-invalid-path");
+		return true;
+	}
+
+	if(!ext)
+	{
+		ext = getKeyword("extension");
+		if(!ext)
+			ext = getSymbol(SYM_EXTENSION);
+		if(ext)
+			strcat(n1, ext);
+	}	
+
+	ext = strrchr(n2, '/');
+	if(ext)
+		ext = strchr(ext, '.');
+	else
+	{
+		error("move-invalid-path");
+		return true;
+	}
+
+	if(!ext)
+	{
+		ext = getKeyword("extension");
+		if(!ext)
+			ext = getSymbol(SYM_EXTENSION);
+		if(ext)
+			strcat(n2, ext);
+	}
+
 	if(rename(n1, n2))
 		error("move-failed");
 	else
@@ -1289,6 +1326,8 @@ bool Trunk::scrErase(void)
 {
 	const char *prefix = getPrefixPath();	
 	const char *name = getValue(NULL);
+	const char *ext;
+	char buffer[128];
 
 	if(!name)
 	{
@@ -1297,14 +1336,27 @@ bool Trunk::scrErase(void)
 	}
 
 	if(prefix)
-	{
-		snprintf(apppath, sizeof(apppath), "%s/%s",
-			prefix, name);
-		remove(apppath);
-	}
+		snprintf(buffer, sizeof(buffer) - 5, "%s/%s", prefix, name);
 	else
-		remove(name);
+		snprintf(buffer, sizeof(buffer) - 5, "%s", name);
 
+	ext = strrchr(buffer, '/');
+	if(ext)
+		ext = strchr(ext, '.');
+	else
+	{
+		error("erase-invalid-path");
+		return true;
+	}
+	if(!ext)
+	{
+		ext = getKeyword("extension");
+		if(!ext)
+			ext = getSymbol(SYM_EXTENSION);
+		if(ext)
+			strcat(buffer, ext);
+	}
+	::remove(buffer);
 	advance();
 	return true;
 }
@@ -3115,6 +3167,7 @@ bool Trunk::scrStart(void)
 	bool start = false;
 	bool ports = false;
 	Name *scr = getObject();
+	const char *cp;
 
 	args[0] = 0;
 
@@ -3244,8 +3297,14 @@ bool Trunk::scrStart(void)
 	strncpy(args + alen, arg, sizeof(args) - alen);
 	alen = strlen(args);
 
+	cp = getSymbol(SYM_GID);
+	if(cp)
+		cp = strchr(cp, '-');
+	else
+		cp = "none";
+
 	if(start || ports || span)
-		snprintf(args + alen, sizeof(args) - alen, " %s=%s", SYM_PARENT, getSymbol(SYM_GID));
+		snprintf(args + alen, sizeof(args) - alen, " %s=%s", SYM_PARENT, cp);
 	alen = strlen(args);
 
 	while(NULL != (arg = getOption(NULL)))
