@@ -145,7 +145,7 @@ static void purge(const char *path)
 	Dir dir(path);
 	char *name;
 
-	while(NULL != (name = dir.getName()))
+	while(NULL != (name = (char *)dir.getName()))
 	{
 		if(!stricmp(name, "."))
 			continue;
@@ -353,13 +353,17 @@ static void tgi(int cfd)
 
 		if(cmd.mode == TGI_EXEC_DETACH)
 		{
+#ifndef	COMMON_PROCESS_ATTACH
 			::close(0);
                 	::close(1);
                		::close(2);
+#endif
                 	Process::detach();
+#ifndef	COMMON_PROCESS_ATTACH
                 	::open("/dev/null", O_RDWR);
                 	::open("/dev/null", O_RDWR);
                 	::open("/dev/null", O_RDWR);
+#endif
 			strcpy(cmds[0], "-detach");
 		}
 		else
@@ -967,13 +971,17 @@ static void initial(int argc, char **argv, int cfd)
 
 	if(daemon)
 	{
+#ifndef	COMMON_PROCESS_ATTACH
 		::close(0);
 		::close(1);
 		::close(2);
+#endif
 		Process::detach();
+#ifndef	COMMON_PROCESS_ATTACH
 		::open("/dev/null", O_RDWR);
 		::open("/dev/null", O_RDWR);
 		::open("/dev/null", O_RDWR);
+#endif
 		mainpid = getpid();
 		slog.open("bayonne", Slog::classDaemon);
 		slog(Slog::levelNotice) << "daemon mode started" << endl;
@@ -1471,7 +1479,7 @@ static void packetio(void)
 
 extern "C" int main(int argc, char **argv)
 {
-	static char buffer[256];
+	static char buffer[PIPE_BUF / 2];
 	static char packet[256];
 	struct sockaddr_un server_addr;
 	char *p;
@@ -1708,7 +1716,7 @@ extern "C" int main(int argc, char **argv)
                                 read(fd, &buffer[bpos], 1);
                                 if(buffer[bpos] == '\n')
                                         break;
-                                if(buffer[bpos] != '\r')
+                                if(buffer[bpos] != '\r' && bpos < sizeof(buffer))
                                         ++bpos;
                         }
                         buffer[bpos] = 0;
