@@ -387,6 +387,82 @@ void Trunk::repSymbol(const char *id, const char *data)
 		setSymbol(id, data);
 }
 
+#ifndef	SCRIPT_SG_VARIABLES
+
+bool Trunk::setVariable(const char *id, int size, const char *value)
+{
+        Symbol *sym;
+        long val;
+
+	if(!id)
+		return false;
+
+	if(*id == '%' || *id == '&')
+		++id;
+
+        if(!size)
+                size = getSymbolSize();
+
+        if(strchr(id, '.'))
+                sym = getEntry(id, size);
+        else
+                sym = getLocal(id, size);
+
+        if(!sym)
+                return false;
+
+        if(!value)
+                return true;
+
+        switch(sym->flags.type)
+        {
+        case SEQUENCE:
+        case CACHE:
+        case FIFO:
+        case STACK:
+                return postSymbol(sym, value);
+        case COUNTER:
+                val = atoi(value);
+                snprintf(sym->data, sym->flags.size + 1, "%ld", --val);
+                break;
+        default:
+                strncpy(sym->data, value, sym->flags.size);
+                sym->data[sym->flags.size] = 0;
+        }
+	sym->flags.initial = false;
+        if(sym->flags.commit)
+                commit(sym);
+
+        return true;
+}
+
+const char *Trunk::getVariable(const char *id)
+{
+        Symbol *sym;
+
+        if(!id)
+                return NULL;
+
+        if(*id == '&' || *id == '&')
+                ++id;
+
+        if(strchr(id, '.'))
+                sym = getEntry(id, 0);
+        else
+                sym = getLocal(id, 0);
+
+        if(!sym)
+                return NULL;
+
+        if(sym->flags.initial)
+                return NULL;
+
+        return readSymbol(sym);
+}
+
+
+#endif
+
 Script::Symbol *Trunk::getEntry(const char *name, int size)
 {
 	int i;
@@ -977,7 +1053,7 @@ bool Trunk::trunkSignal(trunksignal_t signal)
 	Line *line;
 
 	if(!isActive())
-		return true;
+		return false;
 
 	if(signal == TRUNK_SIGNAL_HANGUP)
 	{
